/*
 * Summary: wrappers for structure fields access
 * Description: this module provides wrappers to prevent direct access
 *              to structure fields in applications
 *
 * Author: Emelyanov Alexey
 */

#ifndef __XML_WRAPPERS_H__
#define __XML_WRAPPERS_H__

#include <libxml/xmlversion.h>
#include <libxml/tree.h>

typedef xmlAttributeType xmlAttrType;

#ifdef __cplusplus
extern "C" {
#endif

XMLPUBFUN xmlNodePtr     XMLCALL xmlDocAddChild    (xmlDocPtr  doc, xmlNodePtr node);
XMLPUBFUN xmlNodePtr     XMLCALL xmlDocGetFirst    (xmlDocPtr  doc);
XMLPUBFUN int            XMLCALL xmlDocStandalone  (xmlDocPtr  doc);

XMLPUBFUN xmlElementType XMLCALL xmlGetNodeType    (xmlNodePtr cur);

XMLPUBFUN const xmlChar* XMLCALL xmlGetNodeName    (xmlNodePtr cur);
XMLPUBFUN const xmlChar* XMLCALL xmlGetNodeNs      (xmlNodePtr cur);
XMLPUBFUN const xmlChar* XMLCALL xmlGetNodePrefix  (xmlNodePtr cur);

XMLPUBFUN xmlAttrType    XMLCALL xmlGetPropType    (xmlAttrPtr cur);

XMLPUBFUN const xmlChar* XMLCALL xmlGetPropName    (xmlAttrPtr cur);
XMLPUBFUN const xmlChar* XMLCALL xmlGetPropNs      (xmlAttrPtr cur);
XMLPUBFUN const xmlChar* XMLCALL xmlGetPropPrefix  (xmlAttrPtr cur);

XMLPUBFUN xmlNodePtr     XMLCALL xmlFindNode       (xmlNodePtr top, const xmlChar *name);
XMLPUBFUN xmlNodePtr     XMLCALL xmlFindNodeList   (xmlNodePtr cur, const xmlChar *name);
XMLPUBFUN xmlNodePtr     XMLCALL xmlSkipNode       (xmlNodePtr cur, int skip);
XMLPUBFUN xmlAttrPtr     XMLCALL xmlSkipProp       (xmlAttrPtr cur, int skip);

XMLPUBFUN xmlDocPtr      XMLCALL xmlGetOwnerDoc    (xmlNodePtr cur);
XMLPUBFUN xmlNodePtr     XMLCALL xmlGetParent      (xmlNodePtr cur);

XMLPUBFUN xmlNodePtr     XMLCALL xmlGetFirstChild  (xmlNodePtr cur);
XMLPUBFUN xmlNodePtr     XMLCALL xmlGetPrevNode    (xmlNodePtr cur);
XMLPUBFUN xmlNodePtr     XMLCALL xmlGetNextNode    (xmlNodePtr cur);
XMLPUBFUN xmlAttrPtr     XMLCALL xmlGetFirstProp   (xmlNodePtr cur);
XMLPUBFUN xmlAttrPtr     XMLCALL xmlGetPrevProp    (xmlAttrPtr cur);
XMLPUBFUN xmlAttrPtr     XMLCALL xmlGetNextProp    (xmlAttrPtr cur);

XMLPUBFUN xmlEntityType  XMLCALL xmlGetEntityType  (xmlEntityPtr cur);

XMLPUBFUN const xmlChar* XMLCALL xmlGetEntityName  (xmlEntityPtr cur);
XMLPUBFUN const xmlChar* XMLCALL xmlGetEntityExtID (xmlEntityPtr cur);
XMLPUBFUN const xmlChar* XMLCALL xmlGetEntitySysID (xmlEntityPtr cur);

XMLPUBFUN void *         XMLCALL _xmlRealloc       (void *mem, size_t size);
XMLPUBFUN void *         XMLCALL _xmlMalloc        (size_t size);
XMLPUBFUN void           XMLCALL _xmlFree          (void *mem);

#ifdef __cplusplus
}
#endif

# endif /* __XML_WRAPPERS_H__ */
